@@ -42,8 +42,8 @@ import (
 func newDeployCommand() simplecobra.Commander {
 	return &simpleCommand{
 		name:  "deploy",
-		short: "Deploy your site to a Cloud provider.",
-		long: `Deploy your site to a Cloud provider.
+		short: "Deploy your site to a cloud provider",
+		long: `Deploy your site to a cloud provider
 
 See https://gohugo.io/hosting-and-deployment/hugo-deploy/ for detailed
 documentation.
